"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const MainContainer_1 = __importDefault(require("@web-integration/containers/MainContainer"));
const BalancesWidget_1 = __importDefault(require("@web-integration/widgets/BalancesWidget"));
const LinksWidget_1 = __importDefault(require("@web-integration/widgets/LinksWidget"));
const PaymentWidget_1 = __importDefault(require("@web-integration/widgets/PaymentWidget"));
const FundWidget_1 = __importDefault(require("@web-integration/widgets/FundWidget"));
const contexts_1 = require("@web-integration/contexts");
const constants_1 = require("@web-integration/constants");
const HypernetIFrameProxy_1 = __importDefault(require("@web-integration/implementations/proxy/HypernetIFrameProxy"));
const ConnectorAuthorizationFlow_1 = __importDefault(require("@web-integration/flows/ConnectorAuthorizationFlow"));
class HypernetWebIntegration {
    constructor(iframeURL) {
        this.iframeURL = "http://localhost:8090";
        this.iframeURL = iframeURL || this.iframeURL;
        // Create a container element for the iframe proxy
        this.iframeContainer = document.createElement("div");
        this.iframeContainer.id = "__hypernet-protocol-iframe-container__";
        this.iframeContainer.tabIndex = -1;
        this.iframeContainer.setAttribute("style", "display: none;");
        // Attach it to the body
        document.body.appendChild(this.iframeContainer);
        // Create a proxy connection to the iframe
        this.core = new HypernetIFrameProxy_1.default(this.iframeContainer, this.iframeURL);
    }
    getReady() {
        if (this.getReadyResult != null) {
            return this.getReadyResult;
        }
        this.getReadyResult = this.core
            .activate()
            .andThen(() => {
            return this.core.activate();
        })
            .andThen(() => {
            return this.core.getEthereumAccounts();
        })
            .andThen((accounts) => this.core.initialize(accounts[0]))
            .map(() => this.core);
        return this.getReadyResult;
    }
    // This class must be used as a singleton, this enforces that restriction.
    static getInstance() {
        if (HypernetWebIntegration.instance == null) {
            HypernetWebIntegration.instance = new HypernetWebIntegration();
        }
        return HypernetWebIntegration.instance;
    }
    generateDomElement(selector) {
        this.removeExistedElement(selector);
        const element = document.createElement("div");
        element.setAttribute("id", selector);
        document.body.appendChild(element);
        document.getElementById(selector);
        return element;
    }
    removeExistedElement(selector) {
        const element = document.getElementById(selector);
        if (element) {
            element.remove();
        }
    }
    bootstrapComponent(component, withModal = false) {
        return __awaiter(this, void 0, void 0, function* () {
            return (react_1.default.createElement(contexts_1.StoreProvider, { proxy: this.core },
                react_1.default.createElement(contexts_1.LayoutProvider, null,
                    react_1.default.createElement(MainContainer_1.default, { withModal: withModal }, component))));
        });
    }
    renderBalancesWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this.bootstrapComponent(react_1.default.createElement(BalancesWidget_1.default, null)), this.generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.BALANCES_WIDGET_ID_SELECTOR));
        });
    }
    renderFundWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this.bootstrapComponent(react_1.default.createElement(FundWidget_1.default, null)), this.generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.FUND_WIDGET_ID_SELECTOR));
        });
    }
    renderLinksWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this.bootstrapComponent(react_1.default.createElement(LinksWidget_1.default, null)), this.generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.LINKS_WIDGET_ID_SELECTOR));
        });
    }
    renderPaymentWidget(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this.bootstrapComponent(react_1.default.createElement(PaymentWidget_1.default, { counterPartyAccount: config === null || config === void 0 ? void 0 : config.counterPartyAccount, amount: config === null || config === void 0 ? void 0 : config.amount, expirationDate: config === null || config === void 0 ? void 0 : config.expirationDate, requiredStake: config === null || config === void 0 ? void 0 : config.requiredStake, paymentTokenAddress: config === null || config === void 0 ? void 0 : config.paymentTokenAddress, merchantUrl: config === null || config === void 0 ? void 0 : config.merchantUrl, paymentType: config === null || config === void 0 ? void 0 : config.paymentType }), true), this.generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.PAYMENT_WIDGET_ID_SELECTOR));
        });
    }
    renderConnectorAuthorizationFlow(config) {
        return __awaiter(this, void 0, void 0, function* () {
            react_dom_1.default.render(yield this.bootstrapComponent(react_1.default.createElement(ConnectorAuthorizationFlow_1.default, { connectorUrl: config.connectorUrl, connectorName: config.connectorName, connectorLogoUrl: config.connectorLogoUrl }), config.showInModal), this.generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.BALANCES_WIDGET_ID_SELECTOR));
        });
    }
}
exports.default = HypernetWebIntegration;
window.HypernetWebIntegration = HypernetWebIntegration;
//# sourceMappingURL=HypernetWebIntegration.js.map